Module data

Module data 

Functions

annis_annotation_name
Get the name of the given annotation object.
annis_annotation_ns
Get the namespace of the given annotation object.
annis_annotation_val
Get the value of the given annotation object.
annis_free
Frees the internal object given as ptr argument.
annis_freqtable_str_count
Get the count of the row of the frequency table.
annis_freqtable_str_get
Get a read-only reference to the string at the at position (row, col) of the frequency table.
annis_freqtable_str_ncols
Returns the number of columns of the frequency table.
annis_freqtable_str_nrows
Returns the number of rows of the frequency table.
annis_iter_nodeid_next
Returns a pointer to the next node ID for the iterator given by the ptr argument or NULL if iterator is empty.
annis_matrix_str_get
Get a read-only reference to the string at the at position (row, col) of the matrix.
annis_matrix_str_ncols
Returns the number of columns of the string matrix.
annis_matrix_str_nrows
Returns the number of rows of the string matrix.
annis_str_free
Frees the string given as s argument.
annis_vec_annotation_get
Get a read-only reference to the annotation at position i of the vector.
annis_vec_annotation_size
Returns the number of elements of the annotation vector.
annis_vec_component_get
Get a read-only reference to the component at position i of the vector.
annis_vec_component_size
Returns the number of elements of the component vector.
annis_vec_edge_get
Get a read-only reference to the edge at position i of the vector.
annis_vec_edge_size
Returns the number of elements of the edge vector.
annis_vec_qattdesc_get_anno_name
Create a string representing the annotation name part of the query attribute description.
annis_vec_qattdesc_get_aql_fragment
Create a string representing the AQL fragment part of the query attribute description.
annis_vec_qattdesc_get_component_nr
Get a read-only reference to the query attribute description at position i of the vector.
annis_vec_qattdesc_get_variable
Create a string representing the variable part of the query attribute description.
annis_vec_qattdesc_size
Returns the number of elements of the query attribute description vector.
annis_vec_str_get
Get a read-only reference to the string at position i of the vector.
annis_vec_str_new
Create a new string vector.
annis_vec_str_push
Add an element to the string vector.
annis_vec_str_size
Returns the number of elements of the string vector.
vec_get
vec_size

Type Aliases

IterPtr