#[unsafe(no_mangle)]pub extern "C" fn annis_vec_component_get(
ptr: *const Vec<AnnotationComponent>,
i: size_t,
) -> *const AnnotationComponentExpand description
Get a read-only reference to the component at position i of the vector.
#[unsafe(no_mangle)]pub extern "C" fn annis_vec_component_get(
ptr: *const Vec<AnnotationComponent>,
i: size_t,
) -> *const AnnotationComponentGet a read-only reference to the component at position i of the vector.