annis_graphupdate_delete_node_label

Function annis_graphupdate_delete_node_label 

#[unsafe(no_mangle)]
pub extern "C" fn annis_graphupdate_delete_node_label( ptr: *mut GraphUpdate, node_name: *const c_char, anno_ns: *const c_char, anno_name: *const c_char, err: *mut *mut ErrorList, )
Add “delete node label” action to the graph update object.

  • ptr - The graph update object.
  • node_name - Name of the node the label is attached to.
  • annos_ns - Namespace of deleted new annotation.
  • annos_name - Name of the deleted annotation.
  • err - Pointer to a list of errors. If any error occurred, this list will be non-empty.