Functions
- annis_
annotation_ name - Get the name of the given annotation object.
- annis_
annotation_ ns - Get the namespace of the given annotation object.
- annis_
annotation_ val - Get the value of the given annotation object.
- annis_
free ⚠ - Frees the internal object given as
ptrargument. - annis_
freqtable_ str_ count - Get the count of the
rowof the frequency table. - annis_
freqtable_ str_ get - Get a read-only reference to the string at the at position (
row,col) of the frequency table. - annis_
freqtable_ str_ ncols - Returns the number of columns of the frequency table.
- annis_
freqtable_ str_ nrows - Returns the number of rows of the frequency table.
- annis_
iter_ nodeid_ next - Returns a pointer to the next node ID for the iterator given by the
ptrargument orNULLif iterator is empty. - annis_
matrix_ str_ get - Get a read-only reference to the string at the at position (
row,col) of the matrix. - annis_
matrix_ str_ ncols - Returns the number of columns of the string matrix.
- annis_
matrix_ str_ nrows - Returns the number of rows of the string matrix.
- annis_
str_ ⚠free - Frees the string given as
sargument. - annis_
vec_ annotation_ get - Get a read-only reference to the annotation at position
iof the vector. - annis_
vec_ annotation_ size - Returns the number of elements of the annotation vector.
- annis_
vec_ component_ get - Get a read-only reference to the component at position
iof the vector. - annis_
vec_ component_ size - Returns the number of elements of the component vector.
- annis_
vec_ edge_ get - Get a read-only reference to the edge at position
iof the vector. - annis_
vec_ edge_ size - Returns the number of elements of the edge vector.
- annis_
vec_ qattdesc_ get_ anno_ name - Create a string representing the annotation name part of the query attribute description.
- annis_
vec_ qattdesc_ get_ aql_ fragment - Create a string representing the AQL fragment part of the query attribute description.
- annis_
vec_ qattdesc_ get_ component_ nr - Get a read-only reference to the query attribute description at position
iof the vector. - annis_
vec_ qattdesc_ get_ variable - Create a string representing the variable part of the query attribute description.
- annis_
vec_ qattdesc_ size - Returns the number of elements of the query attribute description vector.
- annis_
vec_ str_ get - Get a read-only reference to the string at position
iof the vector. - annis_
vec_ str_ new - Create a new string vector.
- annis_
vec_ str_ push - Add an element to the string vector.
- annis_
vec_ str_ size - Returns the number of elements of the string vector.
- vec_get
- vec_
size